#!/usr/bin/python

#
# Copyright 2001-2002 Stfane Fermigier and Nuxeo SARL
# See LICENSE.TXT for licensing information
#

import sys, os, unittest, re, glob, string
sys.path.insert(0, '..')
import plugins

class PluginSelectionTestCase(unittest.TestCase):
  "Test plugin selection mechanism (by file / by mime type)"

  def test_selectByMimeType(self):
    self.assertEquals(
      plugins.selectPlugin(None, 'text/rtf').name, 'RTF')
    self.assertEquals(
      plugins.selectPlugin(None, 'application/msword').name, 'MSOffice')
    self.assertEquals(
      plugins.selectPlugin(None, 'application/vnd.ms-powerpoint').name, 
      'MSOffice')
    self.assertEquals(
      plugins.selectPlugin(None, 'application/vnd.ms-excel').name, 
      'MSOffice')
    self.assertEquals(
      plugins.selectPlugin(None, 'application/pdf').name, 'PDF')
    self.assertEquals(
      plugins.selectPlugin(None, 'application/vnd.sun.xml.writer').name, 
      'OpenOffice')
    self.assertEquals(
      plugins.selectPlugin(None, 'text/plain').name, 'Text')

  def test_selectByFileType(self):
    for fn in glob.glob('test[0-9].*'):
      file = open(fn).read()
      plugin_name = plugins.selectPlugin(file, '').name
      if re.match('.*\.(ppt|xls|doc)$', fn):
        self.assertEquals(plugin_name, 'MSOffice')
      elif re.match('.*\.pdf$', fn):
        self.assertEquals(plugin_name, 'PDF')
      elif re.match('.*\.rtf$', fn):
        self.assertEquals(plugin_name, 'RTF')
      elif re.match('.*\.(sxi|sxc|sxw)$', fn):
        self.assertEquals(plugin_name, 'OpenOffice')
      elif re.match('.*\.(htm|html)$', fn):
        self.assertEquals(plugin_name, 'HTML')
      elif re.match('.*\.txt$', fn):
        self.assertEquals(plugin_name, 'Text')
      else:
        self.assertEquals(plugin_name, 'Dumb')


class ConverterTestCase(unittest.TestCase):
  "Test conversion by plugins"

  def test_Base(self):
    doc = plugins.plugin.ConverterBase('toto', 'titi')
    self.assertEquals(doc.getRaw(), 'titi')
    self.assertEquals(doc.getHtml(), '')
    self.assertEquals(doc.getText(), '')
    self.assertEquals(doc.getBody(), '')
    self.assertEquals(doc.getTitle(), '')
    self.assertEquals(doc.getImageNames(), [])
    self.assertRaises(KeyError, doc.getImage, '')

  #
  # MS-Word tests
  #
  def loadMSWordFile(self, name):
    self.result = plugins.MSOffice.getPlugin().getConverter(
      name, open('%s.doc' % name).read())

  def checkWordContentAscii(self):
    test_string = 'Linux rulez. Window$ SuCk$$$.'
    self.assertEquals(string.count(self.result.getHtml(), test_string), 1)
    self.assertEquals(string.count(self.result.getText(), test_string), 1)

  def checkWordContentUnicode(self):
    test_string = 'Il fait chaud en t.'
    self.assertEquals(string.count(self.result.getHtml(), test_string), 1)
    self.assertEquals(string.count(self.result.getText(), test_string), 1)

  def test_MSWord1(self):
    self.loadMSWordFile('test1')
    self.checkWordContentAscii()
    self.assertEquals(self.result.getTitle(), 'Untitled')

  def test_MSWord2(self):
    self.loadMSWordFile('test2')
    self.checkWordContentAscii()

  def test_MSWord3(self):
    self.loadMSWordFile('test3')
    self.checkWordContentAscii()

  def test_MSWord4(self):
    self.loadMSWordFile('test4')
    self.checkWordContentAscii()

    images_names = self.result.getImageNames()
    self.assertEquals(len(images_names), 1)
    self.assertEquals(images_names[0], 'test40.png')
    self.assertEquals(len(self.result.getImage('test40.png')), 5690)

  def test_MSWord5(self):
    self.loadMSWordFile('test5')
    self.checkWordContentUnicode()

  #
  # RTF Tests
  #
  def loadRTFFile(self, name):
    self.result = plugins.RTF.getPlugin().getConverter(
      name, open('%s.rtf' % name).read())

  def test_RTF1(self):
    self.loadRTFFile('test1')
    self.checkWordContentAscii()

  #
  # PDF Tests
  #
  def loadPDFFile(self, name):
    self.result = plugins.PDF.getPlugin().getConverter(
      name, open('%s.rtf' % name).read())

  def test_PDF1(self):
    self.loadRTFFile('test1')
    self.checkWordContentAscii()

  #
  # PPT Tests
  #
  def loadPPTFile(self, name):
    self.result = plugins.MSOffice.getPlugin().getConverter(
      name, open('%s.ppt' % name).read())

  def test_PPT1(self):
    self.loadPPTFile('test1')
    test_string = 'Test de ppthtml'
    self.assertEquals(string.count(self.result.getHtml(), test_string), 1)

  #
  # XLS Tests
  #
  def loadXLSFile(self, name):
    self.result = plugins.MSOffice.getPlugin().getConverter(
      name, open('%s.xls' % name).read())

  def test_XLS1(self):
    self.loadXLSFile('test1')
    test_string = 'Test de xlhtml'
    self.assertEquals(string.count(self.result.getHtml(), test_string), 1)

  #
  # OpenOffice tests
  #
  def loadOOFile(self, name, suffix):
    self.result = plugins.OpenOffice.getPlugin().getConverter(
      name, open('%s.%s' % (name, suffix)).read())

  def test_SXC1(self):
    self.loadOOFile('test1', 'sxc')
    test_string = 'Test de xlhtml'
    res = string.strip(re.sub(r'\W+', ' ', self.result.getText()))
    self.assertEquals(res, test_string)

  def test_SXI1(self):
    self.loadOOFile('test1', 'sxi')
    test_string = 'Test de ppthtml'
    res = string.strip(re.sub(r'\W+', ' ', self.result.getText()))
    self.assertEquals(res, test_string)

  #
  # HTML tests
  #
  def loadHTMLFile(self, name, suffix):
    self.result = plugins.HTML.getPlugin().getConverter(
      name, open('%s.%s' % (name, suffix)).read())

  def test_HTML1(self):
    self.loadHTMLFile('test1', 'html')
    # XXX: fix this
    test_string = 'Le titre Linux rulez Window SuCk'
    res = string.strip(re.sub(r'\W+', ' ', self.result.getText()))
    self.assertEquals(res, test_string)
    self.assertEquals(self.result.getTitle(), 'Le titre')

  #
  # Text tests
  #
  def loadTextFile(self, name, suffix):
    self.result = plugins.Text.getPlugin().getConverter(
      name, open('%s.%s' % (name, suffix)).read())

  def test_Text1(self):
    self.loadTextFile('test1', 'txt')
    test_string = 'Linux rulez Window SuCk'
    res = string.strip(re.sub(r'\W+', ' ', self.result.getText()))
    self.assertEquals(res, test_string)
    res = string.strip(re.sub(r'\W+', ' ', self.result.getBody()))
    self.assertEquals(res, 'pre '+test_string+' pre')

if __name__ == '__main__':
  unittest.main()


